﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using Windows.ApplicationModel;
using Todolist.Commons;
using Todolist.Models;

namespace Todolist.ViewModels
{
    public class MainPageViewModel : BindableBase
    {
        private const string WORKING = "0";
        private const string COMPLETE = "1";
        private const string DELETED = "1";

        /// <summary>
        /// 기본 생성자
        /// </summary>
        public MainPageViewModel()
        {
            Todos = new ObservableCollection<TodoModel>
                {
                    new TodoModel{ Id = 0, Title = "todo0", Content = "todotodo", Status = WORKING, Created = DateTime.Now},
                    new TodoModel{ Id = 1, Title = "todo1", Content = "todotodo", Status = COMPLETE, Created = DateTime.Now},
                    new TodoModel{ Id = 2, Title = "todo2", Content = "todotodo", Status = WORKING, Created = DateTime.Now},
                    new TodoModel{ Id = 3, Title = "todo3", Content = "todotodo", Status = DELETED, Created = DateTime.Now},
                    new TodoModel{ Id = 4, Title = "todo4", Content = "todotodo", Status = COMPLETE, Created = DateTime.Now},
                    new TodoModel{ Id = 5, Title = "todo5", Content = "todotodo", Status = WORKING, Created = DateTime.Now},
                    new TodoModel{ Id = 6, Title = "todo6", Content = "todotodo", Status = WORKING, Created = DateTime.Now},
                    new TodoModel{ Id = 7, Title = "todo7", Content = "todotodo", Status = DELETED, Created = DateTime.Now},
                };

            ViewSelectedIndex = 2;
            CurrentTodo = Todos.FirstOrDefault();

            if (DesignMode.DesignModeEnabled)
            {
            }
            else
            {
                //Todos = new List<TodoModel>();
            }
        }

        /// <summary>
        /// 콤보박스 셀렉티드 인덱스
        /// </summary>
        public int ViewSelectedIndex
        {
            get { return _viewSelectedIndex; }
            set { SetProperty(ref _viewSelectedIndex ,value); }
        }

        public ICollection<TodoModel> Todos { get; set; }

        private TodoModel _currentTodo;
        private int _viewSelectedIndex;

        /// <summary>
        /// CurrentTodo
        /// </summary>
        public TodoModel CurrentTodo
        {
            get { return _currentTodo; }
            set { SetProperty(ref _currentTodo, value); }
        }

        private RelayCommand _addCommand;
        private RelayCommand _saveCommand;
        private RelayCommand _completeCommand;
        private RelayCommand _deleteCommand;

        /// <summary>
        /// 추가 커맨드
        /// </summary>
        public RelayCommand AddCommand
        {
            get 
            { 
                return _addCommand = _addCommand ?? new RelayCommand(() =>
                {
                    if (!Todos.Any()) return;
                    var maxId = Todos.Max(p => p.Id);
                    maxId++;
                    var newItem = new TodoModel
                    {
                        Id = maxId,
                        Title = "new items",
                        Created = DateTime.Now,
                        Status = WORKING,
                    };
                    Todos.Add(newItem);
                    CurrentTodo = newItem;
                }); 
            }
        }
        /// <summary>
        /// 저장
        /// </summary>
        public RelayCommand SaveCommand
        {
            get
            {
                return _saveCommand = _saveCommand ?? new RelayCommand(() =>
                {
                    
                });
            }
        }
        /// <summary>
        /// 완료 커맨드
        /// </summary>
        public RelayCommand CompleteCommand
        {
            get
            {
                return _completeCommand = _completeCommand ?? new RelayCommand(() =>
                {
                    if(CurrentTodo == null) return;
                    CurrentTodo.Status = COMPLETE;
                });
            }
        }
        /// <summary>
        /// 삭제 커맨드
        /// </summary>
        public RelayCommand DeleteCommand
        {
            get
            {
                return _deleteCommand = _deleteCommand ?? new RelayCommand(() => 
                {
                    if(CurrentTodo == null) return;
                    Todos.Remove(CurrentTodo);
                    CurrentTodo = null;
                });
            }
        }
    }
}
